#!/usr/bin/env perl

use strict;
use warnings;
use Test::More;
use Test::Exception;
# setup library path
use FindBin qw($Bin);
use lib "$Bin/lib";
use Data::Dumper;
use Moose::Autobox;
my $path = "$Bin/lib/TestApp/root/";

use_ok 'CatalystX::HelpText::Script::SearchUndocumentedHelpText';

foreach my $suffix ('', '::Regexp') {

    my $class = "CatalystX::HelpText::Finder::TemplateToolkit" . $suffix;
    my $script;
    lives_ok {
        $script = CatalystX::HelpText::Script::SearchUndocumentedHelpText->new(
            help_files_path => "$path/helptext",
            template_search_dir => "$path",
            finder_class => $class,
            filename_pattern => '\W',
        );
    } "don't break";

    my @files = (
        $path.'difficult',
        $path.'undocumented',
        $path.'main',
        $path.'helptext/fnoo.html',
    );
    is_deeply [ sort $script->all_files->flatten ], [ sort @files ], "Files found";
    is_deeply [ sort $script->all_keys->flatten ], [ sort 'undocumented', 'fnoo', 'fnar' ], "All keys found";
    is_deeply [ sort $script->undocumented_keys->flatten ], [ sort 'undocumented', 'fnar' ], "undocumented keys found";
    is_deeply [ sort $script->documented_keys->flatten ], [ sort 'fnoo' ], "documented keys found";

}

done_testing;
